Struct UniformArrayStrategy
pub struct UniformArrayStrategy<S, T> {
strategy: S,
_marker: PhantomData<T>,
}Expand description
A Strategy which generates fixed-size arrays containing values drawn from
an inner strategy.
T must be an array type of length 1 to 32 whose values are produced by
strategy S. Instances of this type are normally created by the various
uniformXX functions in this module.
This is mainly useful when the inner strategy is not Copy, precluding
expressing the strategy as [myStrategy; 32], for example.
Example
use proptest::prelude::*;
proptest! {
#[test]
fn test_something(a in prop::array::uniform32(1u32..)) {
let unexpected = [0u32;32];
// `a` is also a [u32;32], so we can compare them directly
assert_ne!(unexpected, a);
}
}Fields
strategy: S_marker: PhantomData<T>Implementations
impl<S, T> UniformArrayStrategy<S, T>
impl<S, T> UniformArrayStrategy<S, T>
pub fn new(strategy: S) -> UniformArrayStrategy<S, T>
pub fn new(strategy: S) -> UniformArrayStrategy<S, T>
Directly create a UniformArrayStrategy.
This is only intended for advanced use, since the only way to specify the array size is with the turbofish operator and explicitly naming the type of the values in the array and the strategy itself.
Prefer the uniformXX functions at module-level unless something
precludes their use.